@@ -99,10 +99,15 @@ def bfs(matrix, start):
 # print(mst)
 
 
-g5 = fg.Graph()
-g5.load_from_file("tests/input_10.txt")
-dist, par = g5.dijkstra(0)
-print(dist)
-print(par)
+# g5 = fg.Graph()
+# g5.load_from_file("tests/input_10.txt")
+# dist, par = g5.dijkstra(0, 7)
+# print(dist)
+# print(par)
+
+g6 = fg.Graph()
+g6.load_from_file("tests/input_11.txt")
+
+print(g6.max_flow_edmonds_karp(0, 5))
 
 print('✅ Test réussi!')
\ No newline at end of file
